pub struct WindowAttributes {
pub dimensions: Option<(u32, u32)>,
pub min_dimensions: Option<(u32, u32)>,
pub max_dimensions: Option<(u32, u32)>,
pub monitor: Option<MonitorId>,
pub title: String,
pub visible: bool,
pub transparent: bool,
pub decorations: bool,
pub multitouch: bool,
pub icon: Option<PathBuf>,
pub parent: Option<WindowID>,
}Expand description
Attributes to use when creating a window.
Fields
dimensions: Option<(u32, u32)>The dimensions of the window. If this is None, some platform-specific dimensions will be
used.
The default is None.
min_dimensions: Option<(u32, u32)>The minimum dimensions a window can be, If this is None, the window will have no minimum dimensions (aside from reserved).
The default is None.
max_dimensions: Option<(u32, u32)>The maximum dimensions a window can be, If this is None, the maximum will have no maximum or will be set to the primary monitor’s dimensions by the platform.
The default is None.
monitor: Option<MonitorId>If Some, the window will be in fullscreen mode with the given monitor.
The default is None.
title: StringThe title of the window in the title bar.
The default is "glutin window".
visible: boolWhether the window should be immediately visible upon creation.
The default is true.
transparent: boolWhether the the window should be transparent. If this is true, writing colors
with alpha values different than 1.0 will produce a transparent window.
The default is false.
decorations: boolWhether the window should have borders and bars.
The default is true.
multitouch: bool[iOS only] Enable multitouch, see [UIView#multipleTouchEnabled] (https://developer.apple.com/library/ios/documentation/UIKit/Reference/UIView_Class/#//apple_ref/occ/instp/UIView/multipleTouchEnabled)
icon: Option<PathBuf>A path to an icon for the window. This may not be supported on every windowing system. If present, this path must reference a PNG file.
The default is None.
parent: Option<WindowID>Parent Window.
The default is None.